@@ -1,7 +1,6 @@
 import logging
 import os
 import platform
-import shutil
 import socket
 import sys
 import tempfile
@@ -27,7 +26,7 @@ except ImportError:  # pragma: no cover
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "4.0.0"
+__version__ = "4.1.2"
 
 logger = logging.getLogger(__name__)
 
@@ -51,9 +50,9 @@ DEFAULT_RETRY_COUNT = 0
 
 def get_ngrok_bin():
     """
-    Retrieve the `ngrok` command for the current system.
+    Retrieve the :code:`ngrok` executable for the current system.
 
-    :return: The `ngrok` command.
+    :return: The name of the :code:`ngrok` executable.
     :rtype: str
     """
     system = platform.system()
@@ -65,17 +64,15 @@ def get_ngrok_bin():
         raise PyngrokNgrokInstallError("\"{}\" is not a supported platform".format(system))
 
 
-def install_ngrok(ngrok_path, timeout=None):
+def install_ngrok(ngrok_path, **kwargs):
     """
-    Download and install `ngrok` for the current system in the given location.
+    Download and install :code:`ngrok` for the current system in the given location.
 
-    :param ngrok_path: The path to where the `ngrok` binary will be downloaded.
+    :param ngrok_path: The path to where the :code:`ngrok` binary will be downloaded.
     :type ngrok_path: str
-    :param timeout: The request timeout, in seconds.
-    :type timeout: float, optional
+    :param kwargs: Remaining kwargs will be passed to :func:`_download_file`.
+    :type kwargs: dict, optional
     """
-    timeout = timeout if timeout else DEFAULT_DOWNLOAD_TIMEOUT
-
     logger.debug("Binary not found at {}, installing ngrok ...".format(ngrok_path))
 
     ngrok_dir = os.path.dirname(ngrok_path)
@@ -99,22 +96,36 @@ def install_ngrok(ngrok_path, timeout=None):
         raise PyngrokNgrokInstallError("\"{}\" is not a supported platform".format(plat))
 
     try:
-        download_path = _download_file(url, timeout)
+        download_path = _download_file(url, **kwargs)
 
-        with zipfile.ZipFile(download_path, "r") as zip_ref:
-            logger.debug("Extracting ngrok binary to {} ...".format(download_path))
-            zip_ref.extractall(os.path.dirname(ngrok_path))
-
-        os.chmod(ngrok_path, int("777", 8))
+        _install_ngrok_zip(ngrok_path, download_path)
     except Exception as e:
         raise PyngrokNgrokInstallError("An error occurred while downloading ngrok from {}: {}".format(url, e))
 
 
+def _install_ngrok_zip(ngrok_path, zip_path):
+    """
+    Extract the :code:`ngrok` zip file to the given path.
+
+    :param ngrok_path: The path where :code:`ngrok` will be installed.
+    :param zip_path: The path to the :code:`ngrok` zip file to be extracted.
+    """
+    _print_progress("Installing ngrok ... ")
+
+    with zipfile.ZipFile(zip_path, "r") as zip_ref:
+        logger.debug("Extracting ngrok binary to {} ...".format(zip_path))
+        zip_ref.extractall(os.path.dirname(ngrok_path))
+
+    os.chmod(ngrok_path, int("777", 8))
+
+    _clear_progress()
+
+
 def install_default_config(config_path, data=None):
     """
-    Install the default `ngrok` config if one is not already present.
+    Install the default :code:`ngrok` config if one is not already present.
 
-    :param config_path: The path to where the `ngrok` config should be installed.
+    :param config_path: The path to where the :code:`ngrok` config should be installed.
     :type config_path: str
     :param data: A dictionary of things to added to the default config.
     :type data: dict, optional
@@ -143,7 +154,7 @@ def install_default_config(config_path, data=None):
 
 def validate_config(data):
     """
-    Validate that the given dict of config items are valid for `ngrok` and `pyngrok`.
+    Validate that the given dict of config items are valid for :code:`ngrok` and :code:`pyngrok`.
 
     :param data: A dictionary of things to be validated as config items.
     :type data: dict
@@ -152,15 +163,31 @@ def validate_config(data):
         raise PyngrokError("\"web_addr\" cannot be False, as the ngrok API is a dependency for pyngrok")
 
 
-def _download_file(url, timeout, retries=0):
+def _download_file(url, retries=0, **kwargs):
+    """
+    Download a file to a temporary path and emit a status to stdout (if possible) as the download progresses.
+
+    :param url: The URL to download.
+    :type url: str
+    :param retries: The number of retries to attempt, if download fails.
+    :type retries: int, optional
+    :param kwargs: Remaining kwargs will be passed to :py:func:`urllib.request.urlopen`.
+    :type kwargs: dict, optional
+    :return: The path to the downloaded temporary file.
+    :rtype: str
+    """
+    kwargs["timeout"] = kwargs.get("timeout", DEFAULT_DOWNLOAD_TIMEOUT)
+
+    if not url.lower().startswith("http"):
+        raise PyngrokSecurityError("URL must start with \"http\": {}".format(url))
+
     try:
-        if not url.lower().startswith("http"):
-            raise PyngrokSecurityError("URL must start with 'http': {}".format(url))
+        _print_progress("Downloading ngrok ...")
 
         logger.debug("Download ngrok from {} ...".format(url))
 
         local_filename = url.split("/")[-1]
-        response = urlopen(url, timeout=timeout)
+        response = urlopen(url, **kwargs)
 
         status_code = response.getcode()
         logger.debug("Response status code: {}".format(status_code))
@@ -168,16 +195,46 @@ def _download_file(url, timeout, retries=0):
         if status_code != StatusCodes.OK:
             return None
 
-        download_path = os.path.join(tempfile.gettempdir(), local_filename)
+        length = response.getheader("Content-Length")
+        if length:
+            length = int(length)
+            chunk_size = max(4096, length // 100)
+        else:
+            chunk_size = 64 * 1024
 
+        download_path = os.path.join(tempfile.gettempdir(), local_filename)
         with open(download_path, "wb") as f:
-            shutil.copyfileobj(response, f)
+            size = 0
+            while True:
+                buffer = response.read(chunk_size)
+
+                if not buffer:
+                    break
+
+                f.write(buffer)
+                size += len(buffer)
+
+                if length:
+                    percent_done = int((float(size) / float(length)) * 100)
+                    _print_progress("Downloading ngrok: {}%".format(percent_done))
+
+        _clear_progress()
 
         return download_path
     except socket.timeout as e:
         if retries < DEFAULT_RETRY_COUNT:
             time.sleep(0.5)
 
-            return _download_file(url, timeout, retries + 1)
+            return _download_file(url, retries + 1, **kwargs)
         else:
             raise e
+
+
+def _print_progress(line):
+    sys.stdout.write("{}\r".format(line))
+    sys.stdout.flush()
+
+
+def _clear_progress(spaces=100):
+    sys.stdout.write((" " * spaces) + "\r")
+    sys.stdout.flush()
