@@ -27,22 +27,22 @@ except ImportError:  # pragma: no cover
 
 __author__ = "Alex Laird"
 __copyright__ = "Copyright 2020, Alex Laird"
-__version__ = "4.0.1"
+__version__ = "4.1.6"
 
 logger = logging.getLogger(__name__)
 
 
 class NgrokTunnel:
     """
-    An object containing information about an `ngrok` tunnel.
+    An object containing information about a :code:`ngrok` tunnel.
 
     :var name: The name of the tunnel.
     :vartype name: str
     :var proto: A valid `tunnel protocol <https://ngrok.com/docs#tunnel-definitions>`_.
     :vartype proto: str
-    :var uri: The tunnel URI, a relative path that can be used to make requests to the `ngrok` web interface.
+    :var uri: The tunnel URI, a relative path that can be used to make requests to the :code:`ngrok` web interface.
     :vartype uri: str
-    :var public_url: The public `ngrok` URL.
+    :var public_url: The public :code:`ngrok` URL.
     :vartype public_url: str
     :var config: The config for the tunnel.
     :vartype config: dict
@@ -72,10 +72,10 @@ class NgrokTunnel:
 
 def ensure_ngrok_installed(ngrok_path):
     """
-    Ensure `ngrok` is installed at the given path, downloading and installing the binary for
+    Ensure :code:`ngrok` is installed at the given path, downloading and installing the binary for
     the current system if not.
 
-    :param ngrok_path: The path to the `ngrok` binary.
+    :param ngrok_path: The path to the :code:`ngrok` binary.
     :type ngrok_path: str
     """
     if not os.path.exists(ngrok_path):
@@ -87,15 +87,15 @@ def ensure_ngrok_installed(ngrok_path):
 
 def set_auth_token(token, pyngrok_config=None):
     """
-    Set the `ngrok` auth token in the config file, enabling authenticated features (for instance,
+    Set the :code:`ngrok` auth token in the config file, enabling authenticated features (for instance,
     more concurrent tunnels, custom subdomains, etc.).
 
-    If `ngrok` is not installed at the given path, calling this method will first download
-    and install `ngrok`.
+    If :code:`ngrok` is not installed at :class:`~pyngrok.conf.PyngrokConfig`'s :code:`ngrok_path`, calling this method
+    will first download and install :code:`ngrok`.
 
     :param token: The auth token to set.
     :type token: str
-    :param pyngrok_config: The Pyngrok configuration to use when with `ngrok`.
+    :param pyngrok_config: The :code:`pyngrok` configuration to use when interacting with the :code:`ngrok` binary.
     :type pyngrok_config: PyngrokConfig, optional
     """
     if pyngrok_config is None:
@@ -108,16 +108,17 @@ def set_auth_token(token, pyngrok_config=None):
 
 def get_ngrok_process(pyngrok_config=None):
     """
-    Retrieve the current `ngrok` process for the given path.
+    Retrieve the current :code:`ngrok` process for the given config's :code:`ngrok_path`.
 
-    If `ngrok` is not installed at the given path, calling this method will first download
-    and install `ngrok`.
+    If :code:`ngrok` is not installed at :class:`~pyngrok.conf.PyngrokConfig`'s :code:`ngrok_path`, calling this method
+    will first download and install :code:`ngrok`.
 
-    If `ngrok` is not running, calling this method will start a process for the given path.
+    If :code:`ngrok` is not running, calling this method will first start a process with
+    :class:`~pyngrok.conf.PyngrokConfig`.
 
-    :param pyngrok_config: The Pyngrok configuration to use when with `ngrok`.
+    :param pyngrok_config: The :code:`pyngrok` configuration to use when interacting with the :code:`ngrok` binary.
     :type pyngrok_config: PyngrokConfig, optional
-    :return: The `ngrok` process.
+    :return: The :code:`ngrok` process.
     :rtype: NgrokProcess
     """
     if pyngrok_config is None:
@@ -128,25 +129,28 @@ def get_ngrok_process(pyngrok_config=None):
     return process.get_process(pyngrok_config)
 
 
-def connect(port=80, proto="http", name=None, options=None, pyngrok_config=None):
+def connect(port="80", proto="http", name=None, options=None, pyngrok_config=None):
     """
-    Establish a new `ngrok` tunnel to the given port and protocol, returning the connected
+    Establish a new :code:`ngrok` tunnel to the given port and protocol, returning the connected
     public URL that tunnels to the local port.
 
-    If `ngrok` is not installed at the given path, calling this method will first download
-    and install `ngrok`.
+    If :code:`ngrok` is not installed at :class:`~pyngrok.conf.PyngrokConfig`'s :code:`ngrok_path`, calling this method
+    will first download and install :code:`ngrok`.
 
-    If `ngrok` is not running, calling this method will start a process for the given path.
+    If :code:`ngrok` is not running, calling this method will first start a process with
+    :class:`~pyngrok.conf.PyngrokConfig`.
 
-    :param port: The local port to which to tunnel, defaults to 80.
-    :type port: int, optional
+    :param port: The local port to which the tunnel will forward traffic, defaults to "80". Can also be
+        a `local directory or network address <https://ngrok.com/docs#http-file-urls>`_.
+    :type port: str, optional
     :param proto: The protocol to tunnel, defaults to "http".
     :type proto: str, optional
     :param name: A friendly name for the tunnel.
     :type name: str, optional
-    :param options: Parameters passed to `configuration for the ngrok tunnel <https://ngrok.com/docs#tunnel-definitions>`_.
+    :param options: Parameters passed to `configuration for the ngrok
+        tunnel <https://ngrok.com/docs#tunnel-definitions>`_.
     :type options: dict[str, str], optional
-    :param pyngrok_config: The Pyngrok configuration to use when with `ngrok`.
+    :param pyngrok_config: The :code:`pyngrok` configuration to use when interacting with the :code:`ngrok` binary.
     :type pyngrok_config: PyngrokConfig, optional
     :return: The connected public URL.
     :rtype: str
@@ -156,9 +160,16 @@ def connect(port=80, proto="http", name=None, options=None, pyngrok_config=None)
     if pyngrok_config is None:
         pyngrok_config = PyngrokConfig()
 
+    port = str(port)
+    if not name:
+        if not port.startswith("file://"):
+            name = "{}-{}-{}".format(proto, port, uuid.uuid4())
+        else:
+            name = "{}-file-{}".format(proto, uuid.uuid4())
+
     config = {
-        "name": name if name else "{}-{}-{}".format(proto, port, uuid.uuid4()),
-        "addr": str(port),
+        "name": name,
+        "addr": port,
         "proto": proto
     }
     options.update(config)
@@ -170,7 +181,7 @@ def connect(port=80, proto="http", name=None, options=None, pyngrok_config=None)
     tunnel = NgrokTunnel(api_request("{}/api/{}".format(api_url, "tunnels"), method="POST", data=options,
                                      timeout=pyngrok_config.request_timeout))
 
-    if proto == "http" and ("bind_tls" not in options or options["bind_tls"] != False):
+    if proto == "http" and ("bind_tls" not in options or options["bind_tls"] is not False):
         tunnel.public_url = tunnel.public_url.replace("https", "http")
 
     return tunnel.public_url
@@ -178,16 +189,17 @@ def connect(port=80, proto="http", name=None, options=None, pyngrok_config=None)
 
 def disconnect(public_url, pyngrok_config=None):
     """
-    Disconnect the `ngrok` tunnel for the given URL.
+    Disconnect the :code:`ngrok` tunnel for the given URL.
 
-    If `ngrok` is not installed at the given path, calling this method will first download
-    and install `ngrok`.
+    If :code:`ngrok` is not installed at :class:`~pyngrok.conf.PyngrokConfig`'s :code:`ngrok_path`, calling this method
+    will first download and install :code:`ngrok`.
 
-    If `ngrok` is not running, calling this method will start a process for the given path.
+    If :code:`ngrok` is not running, calling this method will first start a process with
+    :class:`~pyngrok.conf.PyngrokConfig`.
 
     :param public_url: The public URL of the tunnel to disconnect.
     :type public_url: str
-    :param pyngrok_config: The Pyngrok configuration to use when with `ngrok`.
+    :param pyngrok_config: The :code:`pyngrok` configuration to use when interacting with the :code:`ngrok` binary.
     :type pyngrok_config: PyngrokConfig, optional
     """
     if pyngrok_config is None:
@@ -200,7 +212,7 @@ def disconnect(public_url, pyngrok_config=None):
         if tunnel.public_url == public_url:
             logger.debug("Disconnecting tunnel: {}".format(tunnel.public_url))
 
-            api_request("{}{}".format(api_url, tunnel.uri.replace("+", "%20")), method="DELETE",
+            api_request("{}{}".format(api_url, tunnel.uri), method="DELETE",
                         timeout=pyngrok_config.request_timeout)
 
             break
@@ -208,16 +220,17 @@ def disconnect(public_url, pyngrok_config=None):
 
 def get_tunnels(pyngrok_config=None):
     """
-    Retrieve a list of all active `ngrok` tunnels.
+    Retrieve a list of active :code:`ngrok` tunnels for the given config's :code:`ngrok_path`.
 
-    If `ngrok` is not installed at the given path, calling this method will first download
-    and install `ngrok`.
+    If :code:`ngrok` is not installed at :class:`~pyngrok.conf.PyngrokConfig`'s :code:`ngrok_path`, calling this method
+    will first download and install :code:`ngrok`.
 
-    If `ngrok` is not running, calling this method will start a process for the given path.
+    If :code:`ngrok` is not running, calling this method will first start a process with
+    :class:`~pyngrok.conf.PyngrokConfig`.
 
-    :param pyngrok_config: The Pyngrok configuration to use when with `ngrok`.
+    :param pyngrok_config: The :code:`pyngrok` configuration to use when interacting with the :code:`ngrok` binary.
     :type pyngrok_config: PyngrokConfig, optional
-    :return: The currently active `ngrok` tunnels.
+    :return: The active :code:`ngrok` tunnels.
     :rtype: list[NgrokTunnel]
     """
     if pyngrok_config is None:
@@ -235,10 +248,10 @@ def get_tunnels(pyngrok_config=None):
 
 def kill(pyngrok_config=None):
     """
-    Terminate the `ngrok` processes, if running, for the given path. This method will not block, it will just issue
-    a kill request.
+    Terminate the :code:`ngrok` processes, if running, for the given config's :code:`ngrok_path`. This method will not
+    block, it will just issue a kill request.
 
-    :param pyngrok_config: The Pyngrok configuration to use when with `ngrok`.
+    :param pyngrok_config: The :code:`pyngrok` configuration to use when interacting with the :code:`ngrok` binary.
     :type pyngrok_config: PyngrokConfig, optional
     """
     if pyngrok_config is None:
@@ -268,7 +281,7 @@ def api_request(url, method="GET", data=None, params=None, timeout=4):
         params = []
 
     if not url.lower().startswith("http"):
-        raise PyngrokSecurityError("URL must start with 'http': {}".format(url))
+        raise PyngrokSecurityError("URL must start with \"http\": {}".format(url))
 
     data = json.dumps(data).encode("utf-8") if data else None
 
@@ -313,9 +326,9 @@ def api_request(url, method="GET", data=None, params=None, timeout=4):
 
 def run(args=None):
     """
-    Start a blocking `ngrok` process with the default binary and the system's command line args.
+    Start a blocking :code:`ngrok` process with the default binary and the passed args.
 
-    :param args: Arguments to be passed to the `ngrok` process.
+    :param args: Arguments to be passed to the :code:`ngrok` process.
     :type args: list[str], optional
     """
     if args is None:
@@ -328,11 +341,11 @@ def run(args=None):
 
 def main():
     """
-    Entry point for console_scripts.
+    Entry point for the package's :code:`console_scripts`.
     """
     run(sys.argv[1:])
 
-    if len(sys.argv) == 1:
+    if len(sys.argv) == 1 or len(sys.argv) == 2 and sys.argv[1].lstrip("-").lstrip("-") == "help":
         print("\nPYNGROK VERSION:\n   {}".format(__version__))
     elif len(sys.argv) == 2 and sys.argv[1].lstrip("-").lstrip("-") in ["v", "version"]:
         print("pyngrok version {}".format(__version__))
